@@ -2,5 +2,12 @@ from .discipline_admin import DisciplineAdmin
 from .training_set_admin import TrainingSetAdmin
 from .document_admin import DocumentAdmin
 from .group_api_key_admin import GroupAPIKeyAdmin
+from .feedback_admin import FeedbackAdmin
 
-__all__ = ["DisciplineAdmin", "TrainingSetAdmin", "DocumentAdmin", "GroupAPIKeyAdmin"]
+__all__ = [
+    "DisciplineAdmin",
+    "TrainingSetAdmin",
+    "DocumentAdmin",
+    "GroupAPIKeyAdmin",
+    "FeedbackAdmin",
+]
